@@ -19,9 +19,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Dict, List, Optional, Any
+from typing import Any, Dict, List, Optional
 
-from .common import ExecutionMatch, ExecutionMode, _BaseDataObject, ExecutionStatus
+from .common import ExecutionMatch, ExecutionMode, ExecutionStatus, _BaseDataObject
 
 
 @dataclass(frozen=True)
@@ -32,8 +32,8 @@ class ExecutionPrimaryFunctionDetails(_BaseDataObject):
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionPrimaryFunctionDetails:
         return cls(
-            error=data.get('error'),
-            output=data.get('output'),
+            error=data.get("error"),
+            output=data.get("output"),
         )
 
 
@@ -48,7 +48,7 @@ class ExecutionDetailsPrimaryFunctions(_BaseDataObject):
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionDetailsPrimaryFunctions:
         return cls(
-            detection=ExecutionPrimaryFunctionDetails.from_json(data.get('detection', {})),
+            detection=ExecutionPrimaryFunctionDetails.from_json(data.get("detection", {})),
         )
 
 
@@ -65,9 +65,9 @@ class ExecutionAuxFunctionDetails(_BaseDataObject):
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionAuxFunctionDetails:
         return cls(
-            defined=data['defined'],
-            error=data['error'],
-            output=data['output'],
+            defined=data["defined"],
+            error=data["error"],
+            output=data["output"],
         )
 
 
@@ -84,26 +84,28 @@ class ExecutionDetailsAuxFunctions(_BaseDataObject):
 
     @property
     def errored(self) -> bool:
-        return self.title.errored \
-               or self.runbook.errored \
-               or self.severity.errored \
-               or self.reference.errored \
-               or self.description.errored \
-               or self.destinations.errored \
-               or self.dedup.errored \
-               or self.alert_context.errored
+        return (
+            self.title.errored
+            or self.runbook.errored
+            or self.severity.errored
+            or self.reference.errored
+            or self.description.errored
+            or self.destinations.errored
+            or self.dedup.errored
+            or self.alert_context.errored
+        )
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionDetailsAuxFunctions:
         return cls(
-            dedup=ExecutionAuxFunctionDetails.from_json(data['dedup']),
-            title=ExecutionAuxFunctionDetails.from_json(data['title']),
-            runbook=ExecutionAuxFunctionDetails.from_json(data['runbook']),
-            severity=ExecutionAuxFunctionDetails.from_json(data['severity']),
-            reference=ExecutionAuxFunctionDetails.from_json(data['reference']),
-            description=ExecutionAuxFunctionDetails.from_json(data['description']),
-            destinations=ExecutionAuxFunctionDetails.from_json(data['destinations']),
-            alert_context=ExecutionAuxFunctionDetails.from_json(data['alert_context']),
+            dedup=ExecutionAuxFunctionDetails.from_json(data["dedup"]),
+            title=ExecutionAuxFunctionDetails.from_json(data["title"]),
+            runbook=ExecutionAuxFunctionDetails.from_json(data["runbook"]),
+            severity=ExecutionAuxFunctionDetails.from_json(data["severity"]),
+            reference=ExecutionAuxFunctionDetails.from_json(data["reference"]),
+            description=ExecutionAuxFunctionDetails.from_json(data["description"]),
+            destinations=ExecutionAuxFunctionDetails.from_json(data["destinations"]),
+            alert_context=ExecutionAuxFunctionDetails.from_json(data["alert_context"]),
         )
 
 
@@ -116,18 +118,20 @@ class ExecutionDetails(_BaseDataObject):
 
     @property
     def errored(self) -> bool:
-        return self.input_error is not None \
-               or self.setup_error is not None \
-               or self.aux_functions.errored \
-               or self.primary_functions.errored
+        return (
+            self.input_error is not None
+            or self.setup_error is not None
+            or self.aux_functions.errored
+            or self.primary_functions.errored
+        )
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionDetails:
         return cls(
-            input_error=data.get('input_error'),
-            setup_error=data.get('setup_error'),
-            aux_functions=ExecutionDetailsAuxFunctions.from_json(data['aux_functions']),
-            primary_functions=ExecutionDetailsPrimaryFunctions.from_json(data['primary_functions']),
+            input_error=data.get("input_error"),
+            setup_error=data.get("setup_error"),
+            aux_functions=ExecutionDetailsAuxFunctions.from_json(data["aux_functions"]),
+            primary_functions=ExecutionDetailsPrimaryFunctions.from_json(data["primary_functions"]),
         )
 
 
@@ -148,9 +152,9 @@ class ExecutionOutput(_BaseDataObject):
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionOutput:
         return cls(
-            match=ExecutionMatch.from_json(data['match']),
-            details=ExecutionDetails.from_json(data['details']),
-            input_id=data['input_id'],
+            match=ExecutionMatch.from_json(data["match"]),
+            details=ExecutionDetails.from_json(data["details"]),
+            input_id=data["input_id"],
         )
 
 
@@ -164,10 +168,10 @@ class ExecutionStats(_BaseDataObject):
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionStats:
         return cls(
-            total_execution_ns=data.get('total_execution_ns', 0),
-            avg_execution_ns=data.get('avg_execution_ns', 0),
-            total_events=data.get('total_events', 0),
-            last_run_ns=data.get('last_run_ns', 0),
+            total_execution_ns=data.get("total_execution_ns", 0),
+            avg_execution_ns=data.get("avg_execution_ns", 0),
+            total_events=data.get("total_events", 0),
+            last_run_ns=data.get("last_run_ns", 0),
         )
 
 
@@ -183,27 +187,27 @@ class ExecutionResult(_BaseDataObject):
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionResult:
         outputs = []
-        for json_str in data['data']:
+        for json_str in data["data"]:
             obj = ExecutionOutput.from_json(json_str)
             outputs.append(obj)
 
         status: Optional[ExecutionStatus] = None
-        data_status = data.get('status')
+        data_status = data.get("status")
         if data_status is not None:
             status = ExecutionStatus(data_status)
         detection_stats: Optional[Dict[str, ExecutionStats]] = None
         raw_stats: Dict[str, Any]
-        if data.get('detection_stats') is not None:
+        if data.get("detection_stats") is not None:
             detection_stats = {}
-            raw_stats = data.get('detection_stats', {})
+            raw_stats = data.get("detection_stats", {})
             for detection_id, value in raw_stats.items():
                 detection_stats[detection_id] = ExecutionStats.from_json(value)
 
         return cls(
-            url=data['url'],
+            url=data["url"],
             status=status,
             detection_stats=detection_stats,
             data=outputs,
-            metadata=data.get('metadata'),
-            output_mode=ExecutionMode(data['output_mode']),
+            metadata=data.get("metadata"),
+            output_mode=ExecutionMode(data["output_mode"]),
         )
