@@ -57,11 +57,7 @@ class FilterConditionBase:
 
     @staticmethod
     def is_valid_dict(data: Dict) -> bool:
-        return (
-            data.get("target", None) is not None
-            and data.get("operator", None) is not None
-            and data.get("value", None) is not None
-        )
+        return data.get("target", None) is not None and data.get("operator", None) is not None
 
 
 class FilterOperator(ABC):  # pylint: disable=too-few-public-methods
