@@ -191,14 +191,9 @@ class Detection(ABC):
         elif isinstance(filts, list) and all(isinstance(f, Filter) for f in filts):
             self.filters = filts
         else:
-            self._setup_exception = TypeError(
+            raise TypeError(
                 "expected 'filters' to be of type Union[List[dict], dict, List[Filter], Filter, None]"
             )
-            self.logger.info(
-                "error while parsing filters for detection %s",
-                self.detection_id,
-                exc_info=self._setup_exception,
-            )
 
         self.skip_filters: bool = bool(config.get("skip_filters"))
 
